﻿SystemOrganization addCategory: #ConfigurationOfNeo4reSt!

Object subclass: #ConfigurationOfNeo4reSt
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfNeo4reSt'!

!ConfigurationOfNeo4reSt commentStamp: '<historical>' prior: 0!
I am ConfigurationOfZincHTTPComponents the Metacello configuration of Zinc HTTP Components, an open-source Smalltalk framework to deal with the HTTP networking protocol.

For more information, see http://homepage.mac.com/svc/Zinc-HTTP-Components

One way to load this project is by executing:

	ConfigurationOfZincHTTPComponents project latestVersion load.
	ConfigurationOfZincHTTPComponents project latestVersion load: 'Tests'.

This is open-source software licensed under the MIT License.!

!ConfigurationOfNeo4reSt class methodsFor: 'private' stamp: 'mu 4/21/2012 23:09'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfNeo4reSt class methodsFor: 'private' stamp: 'mu 4/21/2012 23:09'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfNeo4reSt class methodsFor: 'metacello tool support' stamp: 'mu 4/21/2012 23:09'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfNeo4reSt class methodsFor: 'metacello tool support' stamp: 'mu 4/21/2012 23:09'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfNeo4reSt class methodsFor: 'loading' stamp: 'mu 4/22/2012 00:17'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfNeo4reSt class methodsFor: 'metacello tool support' stamp: 'mu 4/21/2012 23:09'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfNeo4reSt class methodsFor: 'accessing' stamp: 'mu 4/21/2012 23:09'!
project

	^self new project! !

!ConfigurationOfNeo4reSt class methodsFor: 'unloading Metacello' stamp: 'mu 4/21/2012 23:09'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfNeo4reSt methodsFor: 'baselines' stamp: 'mu 4/22/2012 01:14'!
baseline01: spec 
	<version: '0.1-baseline'>
	
	spec for: #common do: [
		spec 
			blessing: #baseline;
			description: 'Baseline for Neo4reSt, a neo4j graph database rest client';
			repository: 'http://ss3.gemstone.com/ss/Neo4reSt'.	
		"spec repository: 'http://squeaksource.blueplane.jp/Neo4reSt'."
		spec
			package: 'JSON' with: [
				spec
					repository: 'http://www.squeaksource.com/JSON' ].

		spec 
			package: 'Neo4reSt-Core';
			package: 'Neo4reSt-Client' with: [ spec requires: #('Neo4reSt-Core' 'JSON')];
			package: 'Neo4reSt-GraphModel' with: [ spec requires: #('Neo4reSt-Core' 'Neo4reSt-Client')];
			package: 'Neo4reSt-IndexModel' with: [ spec requires: #('Neo4reSt-Core' 'Neo4reSt-Client')];
			package: 'Neo4reSt-Traversal' with: [ spec requires: #('Neo4reSt-Core' 'Neo4reSt-Client')];
			package: 'Neo4reSt-Cypher' with: [ spec requires: #('Neo4reSt-Core' 'Neo4reSt-Client')];
			package: 'Neo4reSt-Demo-Dumper' with: [ spec requires: #('Neo4reSt-Core' 'Neo4reSt-Client')];
			package: 'Neo4reSt-Tests' with: [ spec requires: #('Neo4reSt-Core' 'Neo4reSt-Client')].
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Neo4reSt-Core' 'Neo4reSt-Client' 'Neo4reSt-GraphModel' 'Neo4reSt-IndexModel' 'Neo4reSt-Traversal' 'Neo4reSt-Cypher');
			group: 'Demo' with: #('Neo4reSt-Demo-Dumper');
			group: 'Tests' with: #('Neo4reSt-Tests')].
		
	spec for: #squeak do:[
		spec
			project: 'WebClient' with: [
				spec
					className: 'ConfigurationOfWebClient';
					repository: 'http://www.squeaksource.com/WebClient' ].
		spec package: 'Neo4reSt-Squeak-Core' with: [spec requires: 'WebClient'].
		spec group: 'Core' with: #('Neo4reSt-Squeak-Core').	
	].! !

!ConfigurationOfNeo4reSt methodsFor: 'accessing' stamp: 'mu 4/21/2012 23:09'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfNeo4reSt methodsFor: 'accessing' stamp: 'mu 4/22/2012 00:16'!
stable: spec
	<symbolicVersion: #'stable'>! !

!ConfigurationOfNeo4reSt methodsFor: 'versions' stamp: 'mu 4/22/2012 01:15'!
version010: spec 
	<version: '0.1' imports: #('0.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec package: 'JSON' with: 'JSON-ul.35'.
		spec 
			package: 'Neo4reSt-Core' with: 'Neo4reSt-Core-mu.1';
			package: 'Neo4reSt-Client' with: 'Neo4reSt-Client-mu.1';
			package: 'Neo4reSt-GraphModel' with:'Neo4reSt-GraphModel-mu.1';
			package: 'Neo4reSt-IndexModel' with:'Neo4reSt-IndexModel-mu.1';
			package: 'Neo4reSt-Traversal' with:'Neo4reSt-Traversal-mu.1';
			package: 'Neo4reSt-Cypher' with:'Neo4reSt-Cypher-mu.1';
			package: 'Neo4reSt-Demo-Dumper' with:'Neo4reSt-Demo-Dumper-mu.1';
			package: 'Neo4reSt-Tests' with:'Neo4reSt-Tests-mu.1'.
		].
		
	spec for: #squeak do:[
		spec blessing: #beta.
		spec project: 'WebClient' with: '1.3'.
		spec 
			package: 'Neo4reSt-Squeak-Core' with: 'Neo4reSt-Squeak-Core-mu.1'		
		]! !

!ConfigurationOfNeo4reSt methodsFor: 'versions' stamp: 'mu 4/22/2012 23:10'!
version011: spec 
	<version: '0.1' imports: #('0.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec package: 'JSON' with: 'JSON-ul.35'.
		spec 
			package: 'Neo4reSt-Core' with: 'Neo4reSt-Core-mu.2';
			package: 'Neo4reSt-Client' with: 'Neo4reSt-Client-mu.3';
			package: 'Neo4reSt-GraphModel' with:'Neo4reSt-GraphModel-mu.3';
			package: 'Neo4reSt-IndexModel' with:'Neo4reSt-IndexModel-mu.1';
			package: 'Neo4reSt-Traversal' with:'Neo4reSt-Traversal-mu.1';
			package: 'Neo4reSt-Cypher' with:'Neo4reSt-Cypher-mu.1';
			package: 'Neo4reSt-Demo-Dumper' with:'Neo4reSt-Demo-Dumper-mu.1';
			package: 'Neo4reSt-Tests' with:'Neo4reSt-Tests-mu.2'.
		].
		
	spec for: #squeak do:[
		spec blessing: #beta.
		spec project: 'WebClient' with: '1.3'.
		spec package: 'Neo4reSt-Squeak-Core' with: 'Neo4reSt-Squeak-Core-mu.3'		
	].

	spec for: #pharo do:[
		spec blessing: #beta.
		spec package: 'Neo4reSt-Pharo-Core' with: 'Neo4reSt-Pharo-Core-MasashiUmezawa.1'		
	].! !
